import * as pg from "pg";
/**
 * PostgreSQL client class
 *
 * @export
 * @class PostgreSQL
 */
export declare class PostgreSQL {
    private options;
    /**
     * `pg` client
     * @see https://node-postgres.com/
     *
     * @type {pg.Client}
     */
    client: pg.Client;
    constructor(options: pg.ClientConfig);
    /**
     * Connects the client to the database
     *
     * @returns {Promise<void>}
     */
    connect(): Promise<void>;
    /**
     * Disconnects the client from the database
     *
     * @returns {Promise<void>}
     */
    disconnect(): Promise<void>;
    /**
     * Execute a raw query (command)
     *
     * @param {string} query Query, eg: `SELECT * FROM guilds;`
     * @returns {Promise<string>}
     */
    rawQuery(query: string): Promise<string>;
    /**
     * Insert data into a table
     *
     * @param {string} table Table to query
     * @param {*} data Data to insert
     * @returns {Promise<pg.QueryResult>}
     */
    insert(table: string, data: any): Promise<pg.QueryResult>;
    /**
     * Update data in a table
     *
     * @example PostgreSQL.update('nya', 'id = "awoo"', { reee: true });
     *
     * @param {string} table Table to query
     * @param {string} expression Expression, eg: `id = 123456, name = "awoo"`
     * @param {*} data New data
     * @returns {Promise<pg.QueryResult>}
     */
    update(table: string, expression: string, data: any): Promise<pg.QueryResult>;
    /**
     * Select data from database
     *
     * @example PostgreSQL.select('nyan', 'id = "awoo"')
     *
     * @param {string} table Table to query
     * @param {string} expression Expression, eg: `id = 123456, name = "awoo"`
     * @returns {Promise<pg.QueryResult>}
     */
    select(table: string, expression: string): Promise<pg.QueryResult>;
}
