import { Context } from "./Context";
export interface ICommandArg {
    name: string;
    optional: boolean;
    type: string;
}
export interface ICommandFlag {
    flag: string;
    abbr: string;
}
export interface ICommandPermission {
    name: string;
    optional: boolean;
}
/**
 * Command class
 *
 * @export
 * @class Command
 */
export declare class Command {
    /**
     * Name of the command
     *
     * @type {string}
     */
    name: string;
    /**
     * Description of the command
     *
     * @type {string}
     */
    desc: string;
    /**
     * Arguments on the command
     *
     * @type {ICommandArg[]}
     */
    args: ICommandArg[];
    /**
     * Flags on the command
     *
     * @type {ICommandFlag[]}
     */
    flags: ICommandFlag[];
    /**
     * Permissions on the command
     *
     * @type {ICommandPermission[]}
     */
    perms: ICommandPermission[];
    /**
     * Permissions for the bot on the command
     *
     * @type {ICommandPermission[]}
     */
    botPerms: ICommandPermission[];
    /**
     * Subcommands on the command
     *
     * @type {Array<(ctx: Context) => any>}
     */
    subcommands: Array<(ctx: Context) => any>;
    /**
     * Whether the command is owner only or not
     *
     * @type {boolean}
     */
    ownerOnly: boolean;
    /**
     * Will be run when the command is executed
     *
     * @param {Context} ctx Context
     * @returns {Promise<any>}
     */
    run(ctx: Context): Promise<any>;
}
